@@ -50,7 +50,8 @@ from aiohttp.client import ClientTimeout
 from aiohttp.client import ServerTimeoutError
 from tqdm.asyncio import tqdm_asyncio  # type: ignore[import]
 
-from ..aws_data import AWSContext
+from cfn_lsp_extra.aws_data import AWSContextMap
+
 from ..aws_data import AWSName
 from ..aws_data import AWSPropertyName
 from ..aws_data import AWSResourceName
@@ -64,10 +65,10 @@ T = TypeVar("T")
 
 class BaseCfnDocParser(ABC):
 
-    HEADER_REGEX: Pattern[str] = re.compile(r"^`([a-zA-Z0-9]+)`.*<a*.a>")
+    HEADER_REGEX: Pattern[str] = re.compile(r"^\s*`([a-zA-Z0-9]+)`.*<a*.a>")
     SUB_PROP_REGEX: Pattern[str] = re.compile(r"^\*Type\*:.*\[(.*)\]\((.*\.md)\)")
     PROPERTY_LINE_PREFIX = "## Properties"
-    PROPERTY_END_PREFIX = "## Return values"
+    PROPERTY_END_PREFIX = "##"
     TEXT_WRAPPER = MarkdownTextWrapper(
         width=79,
         break_long_words=True,
@@ -113,7 +114,7 @@ class BaseCfnDocParser(ABC):
                     return None
         except ServerTimeoutError as e:
             if retry:
-                logger.info("Timeout for %s, retrying", url)
+                logger.debug("Timeout for %s, retrying", url)
                 return await self.parse(session, url, False)
             else:
                 raise e
@@ -157,7 +158,7 @@ class BaseCfnDocParser(ABC):
                 desc += line
 
         if prop_name is None:
-            logger.info("Skipping %s since no properties were found", name)
+            logger.debug("Skipping %s since no properties were found", name)
             return None
         properties[prop_name.property_] = {
             "description": self.format_description(desc),
@@ -169,7 +170,7 @@ class BaseCfnDocParser(ABC):
     async def parse_subproperty(
         self, session: ClientSession, property_name: AWSPropertyName, url: str
     ) -> Optional[Tree]:
-        logger.info("parsing %s", property_name)
+        logger.debug("parsing %s", property_name)
         if self.ignore_condition(property_name):
             return None
         else:
@@ -187,6 +188,7 @@ class BaseCfnDocParser(ABC):
         return description
 
     def format_description(self, description: str) -> str:
+        description = re.sub(r"`\[(.*?)\]\((\S+)\)`", r"[`\1`](\2)", description)
         first_line, *rest = description.splitlines()
         body = ""
         for line in filter(lambda l: l.strip(), rest):
@@ -252,17 +254,18 @@ class CfnPropertyDocParser(BaseCfnDocParser):
         return {"description": description, "properties": properties}
 
 
-BASE_URL = "https://raw.githubusercontent.com/awsdocs/aws-cloudformation-user-guide/main/doc_source/"  # noqa
+BASE_URL = "https://raw.githubusercontent.com/awsdocs/aws-cloudformation-user-guide/main/doc_source"  # noqa
+SAM_BASE_URL = "https://raw.githubusercontent.com/awsdocs/aws-sam-developer-guide/main/doc_source"  # noqa
 
 
-async def parse_urls(urls: List[str], base_url: str = BASE_URL) -> AWSContext:
+async def parse_urls(urls: List[str], base_url: str = BASE_URL) -> AWSContextMap:
     parser = CfnResourceDocParser(base_url)
     async with aiohttp.ClientSession() as session:
         resources = await tqdm_asyncio.gather(
             *[parser.parse(session, url) for url in urls]
         )
-        return AWSContext(
-            resources={
+        return AWSContextMap(
+            {
                 res["name"]: {
                     "description": res["description"],
                     "properties": res["properties"],
